/***************************************************************************
 *
 * $Header: /usr/local/cvsroot/utils/ytree/edit.c,v 1.12 2001/02/03 15:58:51 werner Exp $
 *
 * Edit-Kommando-Bearbeitung
 *
 ***************************************************************************/


#include "ytree.h"




int Edit(char *file_path)
{
  char *command_line;
  int  result = -1;
  char *file_p_aux=NULL;

  if( mode != DISK_MODE && mode != USER_MODE )
  {
    beep();
    return( -1 );
  }

  if( access( file_path, R_OK ) )
  {
    (void) sprintf( message, 
		    "Edit not possible!*\"%s\"*%s", 
		    file_path, 
		    sys_errlist[errno] 
		  );
    MESSAGE( message );
    ESCAPE;
  }

  if( ( file_p_aux = (char *)malloc( COMMAND_LINE_LENGTH ) ) == NULL )
  {
    ERROR_MSG( "Malloc failed*ABORT" );
    exit( 1 );
  }
  StrCp(file_p_aux, file_path);

  if( ( command_line = (char *)malloc( COMMAND_LINE_LENGTH ) ) == NULL )
  {
    ERROR_MSG( "Malloc failed*ABORT" );
    exit( 1 );
  }
  (void) strcpy( command_line, EDITOR );
  (void) strcat( command_line, " " );
  (void) strcat( command_line, file_p_aux );
  free( file_p_aux);
  result = SystemCall( command_line );
  free( command_line );
 
FNC_XIT:

  return( result );
}



